@@ -1,10 +1,12 @@
-from .Elki import Elki
-from prefect.tasks.shell import ShellTask
-from prefect import Flow
-import pandas as pd
 import io
+import warnings
+
+import pandas as pd
+from prefect import Flow
+from prefect.tasks.shell import ShellTask
 
 from .cte import ELKI_FILEPATH
+from .Elki import Elki
 
 
 class Hics(Elki):
@@ -22,7 +24,7 @@ class Hics(Elki):
         super().fit(X)
 
         self.status = self.fit_flow.run()
-        raw = self.status.result[self.fit_shell_task].result.copy()
+        raw = self.status.result[self.fit_shell_task].result
         res = self._filter_raw(raw, X.shape[0])
 
         # Process
@@ -37,10 +39,37 @@ class Hics(Elki):
         del raw
         del res
         self.fit_shell_task = None
-        self.status = None
 
         return
 
+
+    # --------------
+    # Parameter - Properties
+    # --------------
+    @property
+    def k(self):
+        # One more setter-call to ensure the value is correct!
+        self.k = self._k
+        return self._k
+
+    @k.setter
+    def k(self, value):
+        self._k = self._compatible_k_n_instances(value)
+        return 
+
+    def _compatible_k_n_instances(self, k):
+        if self.n_instances is None:
+            return k
+        else:
+            res = min(k, self.n_instances-1)
+            if res < k:
+                msg = """
+                k was set to {}, but n_instances is {}.
+                ELKI won't have this. Changed k to {}
+                """.format(k, self.n_instances, res)
+                warnings.warn(msg)
+            return res
+
     # --------------
     # Internal Methods
     # --------------
